pub struct FromUtf8Error<'borrow, B>where
B: Backend,{ /* private fields */ }Expand description
A possible error value when converting a HipStr from a HipByt.
This type is the error type for the from_utf8 method on HipStr. It
is designed in such a way to carefully avoid reallocations: the
into_bytes method will give back the byte vector that was used in the
conversion attempt.
The Utf8Error type provided by std::str represents an error that may
occur when converting a slice of u8s to a &str. In this sense, it’s
an analogue to FromUtf8Error, and you can get one from a FromUtf8Error
through the utf8_error method.
Examples
Basic usage:
// some invalid bytes, in a vector
let bytes = vec![0, 159];
let value = String::from_utf8(bytes);
assert!(value.is_err());
assert_eq!(vec![0, 159], value.unwrap_err().into_bytes());Implementations
Sourceimpl<'borrow, B> FromUtf8Error<'borrow, B>where
B: Backend,
impl<'borrow, B> FromUtf8Error<'borrow, B>where
B: Backend,
Sourcepub fn into_bytes(self) -> HipByt<'borrow, B>
pub fn into_bytes(self) -> HipByt<'borrow, B>
Returns the bytes that were attempted to convert to a HipStr.
This method is carefully constructed to avoid allocation. It will consume the error, moving out the bytes, so that a copy of the bytes does not need to be made.
Examples
Basic usage:
// some invalid bytes, in a vector
let bytes = HipByt::from(vec![0, 159]);
let value = HipStr::from_utf8(bytes.clone());
assert_eq!(bytes, value.unwrap_err().into_bytes());Sourcepub const fn utf8_error(&self) -> Utf8Error
pub const fn utf8_error(&self) -> Utf8Error
Fetch a Utf8Error to get more details about the conversion failure.
The Utf8Error type provided by std::str represents an error that may
occur when converting a slice of u8s to a &str. In this sense, it’s
an analogue to FromUtf8Error. See its documentation for more details
on using it.
Examples
Basic usage:
// some invalid bytes, in a vector
let bytes = HipByt::from(vec![0, 159]);
let error = HipStr::from_utf8(bytes).unwrap_err().utf8_error();
// the first byte is invalid here
assert_eq!(1, error.valid_up_to());Trait Implementations
Sourceimpl<B> Clone for FromUtf8Error<'_, B>where
B: Backend,
impl<B> Clone for FromUtf8Error<'_, B>where
B: Backend,
Sourceimpl<B> Debug for FromUtf8Error<'_, B>where
B: Backend,
impl<B> Debug for FromUtf8Error<'_, B>where
B: Backend,
Sourceimpl<B> Display for FromUtf8Error<'_, B>where
B: Backend,
impl<B> Display for FromUtf8Error<'_, B>where
B: Backend,
Sourceimpl<B> Error for FromUtf8Error<'_, B>where
B: Backend,
impl<B> Error for FromUtf8Error<'_, B>where
B: Backend,
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
use the Display impl or to_string()